#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.resources"), aligned (8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[1311]; const double alignment; void * const ptr;}  resources_resource_data = { {
  0x47, 0x56, 0x61, 0x72, 0x69, 0x61, 0x6e, 0x74, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x18, 0x00, 0x00, 0x00, 0xc8, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x28, 0x06, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 
  0x03, 0x00, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00, 
  0x06, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 
  0x4a, 0x70, 0xbe, 0x68, 0x03, 0x00, 0x00, 0x00, 
  0xc8, 0x00, 0x00, 0x00, 0x05, 0x00, 0x4c, 0x00, 
  0xd0, 0x00, 0x00, 0x00, 0xd4, 0x00, 0x00, 0x00, 
  0x6c, 0x32, 0xbf, 0x2f, 0x00, 0x00, 0x00, 0x00, 
  0xd4, 0x00, 0x00, 0x00, 0x06, 0x00, 0x4c, 0x00, 
  0xdc, 0x00, 0x00, 0x00, 0xe0, 0x00, 0x00, 0x00, 
  0x4b, 0x50, 0x90, 0x0b, 0x04, 0x00, 0x00, 0x00, 
  0xe0, 0x00, 0x00, 0x00, 0x04, 0x00, 0x4c, 0x00, 
  0xe4, 0x00, 0x00, 0x00, 0xe8, 0x00, 0x00, 0x00, 
  0xb0, 0xb7, 0x24, 0x30, 0x02, 0x00, 0x00, 0x00, 
  0xe8, 0x00, 0x00, 0x00, 0x06, 0x00, 0x4c, 0x00, 
  0xf0, 0x00, 0x00, 0x00, 0xf4, 0x00, 0x00, 0x00, 
  0xd4, 0xb5, 0x02, 0x00, 0xff, 0xff, 0xff, 0xff, 
  0xf4, 0x00, 0x00, 0x00, 0x01, 0x00, 0x4c, 0x00, 
  0xf8, 0x00, 0x00, 0x00, 0xfc, 0x00, 0x00, 0x00, 
  0xb3, 0xb4, 0xa3, 0x72, 0x01, 0x00, 0x00, 0x00, 
  0xfc, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x76, 0x00, 
  0x10, 0x01, 0x00, 0x00, 0x1f, 0x05, 0x00, 0x00, 
  0x67, 0x69, 0x74, 0x67, 0x2f, 0x00, 0x00, 0x00, 
  0x01, 0x00, 0x00, 0x00, 0x66, 0x69, 0x6c, 0x65, 
  0x73, 0x2f, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00, 
  0x6f, 0x72, 0x67, 0x2f, 0x03, 0x00, 0x00, 0x00, 
  0x67, 0x6e, 0x6f, 0x6d, 0x65, 0x2f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x2f, 0x00, 0x00, 0x00, 
  0x02, 0x00, 0x00, 0x00, 0x76, 0x69, 0x65, 0x77, 
  0x2d, 0x66, 0x69, 0x6c, 0x65, 0x73, 0x2e, 0x75, 
  0x69, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0xbf, 0x08, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x78, 0xda, 0xbd, 0x56, 0x4d, 0x73, 0xda, 0x30, 
  0x10, 0xbd, 0xe7, 0x57, 0xb8, 0xba, 0x76, 0x1c, 
  0x48, 0x7b, 0xe9, 0x01, 0x3b, 0x93, 0x52, 0x48, 
  0x67, 0x3a, 0x69, 0x32, 0xe0, 0xb4, 0x47, 0x8d, 
  0x90, 0x17, 0xbc, 0x45, 0x96, 0xa8, 0x24, 0x03, 
  0xc9, 0xaf, 0xaf, 0x6c, 0xb9, 0x86, 0xa9, 0x29, 
  0xf6, 0x74, 0xa6, 0xdc, 0xf4, 0xb1, 0x2b, 0xbd, 
  0x7d, 0x6f, 0xf5, 0xec, 0xd1, 0xed, 0x3e, 0x17, 
  0xc1, 0x16, 0xb4, 0x41, 0x25, 0x23, 0x72, 0x73, 
  0x3d, 0x24, 0x01, 0x48, 0xae, 0x52, 0x94, 0xab, 
  0x88, 0x3c, 0x27, 0xd3, 0xf0, 0x03, 0xb9, 0x8d, 
  0xaf, 0x46, 0x28, 0x2d, 0xe8, 0x25, 0xe3, 0x10, 
  0x8f, 0xde, 0x84, 0x61, 0xd0, 0x4c, 0x43, 0x0d, 
  0x3f, 0x0b, 0xd4, 0x60, 0x82, 0x95, 0x5d, 0xbf, 
  0x0d, 0xde, 0x5f, 0x0f, 0x83, 0x30, 0x3c, 0x17, 
  0x63, 0x54, 0xa1, 0x39, 0x6c, 0x11, 0x76, 0x4d, 
  0xb0, 0x5a, 0xfc, 0x00, 0x6e, 0x03, 0x2e, 0x98, 
  0x31, 0x11, 0xb9, 0xb7, 0xeb, 0x79, 0x15, 0xf3, 
  0xb1, 0x58, 0x2e, 0x41, 0x93, 0x00, 0xd3, 0x88, 
  0xf8, 0x2c, 0xba, 0xa8, 0x96, 0xe8, 0x12, 0x05, 
  0x90, 0xc1, 0x89, 0xc4, 0x27, 0x26, 0x21, 0xf5, 
  0x19, 0x9b, 0x72, 0x58, 0x45, 0x1a, 0x12, 0x8f, 
  0x36, 0x5a, 0x6d, 0x40, 0xdb, 0x97, 0x40, 0xb2, 
  0x1c, 0x22, 0xb2, 0x45, 0x83, 0x0b, 0x77, 0x46, 
  0x9c, 0xe8, 0x02, 0x46, 0x83, 0xdf, 0xbb, 0xad, 
  0x38, 0xce, 0x24, 0x5d, 0x2a, 0x5e, 0x98, 0xce, 
  0xc8, 0x8d, 0x32, 0x68, 0x1d, 0x85, 0x24, 0x7e, 
  0x37, 0x1c, 0x1e, 0xc7, 0xf1, 0x0c, 0x45, 0x7a, 
  0xaa, 0x46, 0xae, 0x95, 0x10, 0x90, 0x7e, 0x47, 
  0x99, 0xaa, 0x5d, 0x5d, 0x65, 0xbd, 0x46, 0x77, 
  0xd5, 0xe2, 0x7f, 0x44, 0xff, 0x37, 0x54, 0x89, 
  0x06, 0xf8, 0xe6, 0xb4, 0xf1, 0x78, 0xac, 0x9b, 
  0xd1, 0x52, 0xaa, 0xcb, 0xf1, 0x98, 0x01, 0x4b, 
  0x5d, 0x33, 0xd2, 0xe6, 0xe4, 0x29, 0x13, 0xa6, 
  0x4f, 0x02, 0x17, 0xc8, 0xd7, 0xac, 0x57, 0x8a, 
  0x01, 0xa6, 0x79, 0x46, 0xb9, 0x12, 0x45, 0xee, 
  0x04, 0x6b, 0xcb, 0xe5, 0x5b, 0x57, 0x32, 0x11, 
  0x56, 0xd3, 0x32, 0x43, 0x38, 0x9e, 0x2a, 0x79, 
  0x4f, 0x73, 0x36, 0x6f, 0x02, 0x1a, 0xe2, 0x4a, 
  0xde, 0xc2, 0x43, 0xa2, 0x6b, 0xd7, 0x41, 0xcd, 
  0x7a, 0x17, 0xf9, 0x63, 0x0f, 0xec, 0x0f, 0x09, 
  0x3c, 0x5c, 0xdf, 0xfb, 0xed, 0x92, 0xf0, 0xd5, 
  0x3d, 0x58, 0x12, 0xb3, 0xc2, 0xba, 0x46, 0x7c, 
  0x3d, 0x57, 0xbd, 0x45, 0xeb, 0x4e, 0x08, 0xac, 
  0x66, 0xd2, 0x08, 0x66, 0x4b, 0xca, 0x22, 0xf2, 
  0x52, 0xaa, 0xeb, 0x6f, 0xe8, 0xd3, 0x26, 0x63, 
  0x10, 0x62, 0x06, 0xd2, 0x11, 0x0f, 0xfa, 0x09, 
  0xf7, 0xee, 0x59, 0x7a, 0xb4, 0xdc, 0xad, 0x53, 
  0x5d, 0x6f, 0x50, 0xe4, 0xbe, 0x6e, 0x66, 0xad, 
  0xc6, 0x45, 0x61, 0xc1, 0x1c, 0x8d, 0x6b, 0x34, 
  0xab, 0x2a, 0xa8, 0xd4, 0xa0, 0xd9, 0x89, 0x8f, 
  0xc6, 0xa6, 0x9b, 0xb5, 0x63, 0x2c, 0x09, 0xec, 
  0xed, 0x29, 0x24, 0xe5, 0x5d, 0x5d, 0x48, 0x6c, 
  0x99, 0x1b, 0xdf, 0x74, 0x03, 0x19, 0x78, 0x08, 
  0x7d, 0x16, 0x36, 0x8c, 0xaf, 0x9d, 0x2e, 0x2d, 
  0x0d, 0x9c, 0x17, 0x3a, 0x91, 0x7a, 0x74, 0x6a, 
  0xa6, 0x51, 0xae, 0xdb, 0x8f, 0x66, 0xd0, 0x1c, 
  0xdc, 0xc5, 0x4e, 0x5f, 0x9b, 0xb9, 0xa8, 0xcb, 
  0x78, 0x7f, 0x3f, 0xf8, 0x4c, 0xed, 0xee, 0x8d, 
  0xd3, 0x5c, 0xc2, 0x68, 0xfc, 0xa7, 0x84, 0xc4, 
  0xed, 0x2f, 0xcb, 0x59, 0x3d, 0x1c, 0x5d, 0x02, 
  0x25, 0x50, 0x59, 0xe4, 0x0b, 0x67, 0x3b, 0x9d, 
  0xd7, 0x54, 0x19, 0x1a, 0x57, 0x99, 0xa5, 0x39, 
  0xd3, 0x2b, 0x94, 0xdd, 0x19, 0x2e, 0xce, 0xd2, 
  0x4c, 0xe5, 0x40, 0x5d, 0xfb, 0x92, 0xf8, 0x3e, 
  0xf9, 0x42, 0xe7, 0x8f, 0xcf, 0xb3, 0xf1, 0x84, 
  0xce, 0x1f, 0xee, 0x66, 0x09, 0xfd, 0xfc, 0xf8, 
  0x30, 0xa1, 0x93, 0xaf, 0x9f, 0xe8, 0xdd, 0x34, 
  0x99, 0xcc, 0xce, 0x9c, 0x04, 0x29, 0xda, 0x7e, 
  0x8e, 0xc8, 0x0b, 0x6d, 0x94, 0x3e, 0x63, 0xba, 
  0xff, 0xde, 0xe2, 0x9d, 0xfc, 0xf4, 0xed, 0xf0, 
  0x03, 0x84, 0xc3, 0xbf, 0xc8, 0xd5, 0x2f, 0xd3, 
  0xf8, 0x33, 0x17, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x28, 0x75, 0x75, 0x61, 0x79, 0x29
} };

static GStaticResource static_resource = { resources_resource_data.data, sizeof (resources_resource_data.data), NULL, NULL, NULL };
extern GResource *resources_get_resource (void);
GResource *resources_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a sane way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for Win32 (x86) and x64 programs, as symbols on Win32 are prefixed
 * with an underscore but symbols on x64 are not.
 */
#ifdef _WIN64
#define G_MSVC_SYMBOL_PREFIX ""
#else
#define G_MSVC_SYMBOL_PREFIX "_"
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
